#  Copyright (c) 2010 Vitja Makarov
#
#  Author: Vitja Makarov <vitja.makarov@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from uirk.progress.text import TextBuildISOProgress
from uirk.utils import which, InstallationError, OperationError

class BuildISO(object):
    def __init__(self, output, srcdir, label=None, boot_image=None, boot_catalog=None, verbose=False):
        self._output = output
        self._srcdir = srcdir
        self._label = label
        self._boot_image = boot_image
        self._boot_catalog = boot_catalog
        self.verbose = verbose

    def run(self, progress=None):

        ## First of all
        mkiso_exec = which('genisoimage')

        if mkiso_exec is None:
            mkiso_exec = which('mkisofs')

        if mkiso_exec is None:
            raise InstallationError, "Could not find genisoimage or mkisofs executable, please install one of these packages"

        args = ['mkisofs', '-r', '-o', self._output, '-J', '-l', '-cache-inodes']

        if self._label:
            args += ['-V', self._label[:32]]
        if self._boot_image:
            args += ['-b', self._boot_image, '-no-emul-boot', '-boot-load-size', '4', '-boot-info-table']
            if self._boot_catalog:
                args += ['-c', self._boot_catalog]
        args += [self._srcdir]

        if progress is None:
            progress = TextBuildISOProgress
        progress = progress(verbose=self.verbose, obj=self)
        ret = progress.run(self, mkiso_exec, args)
        if ret != 0:
            raise OperationError, "mkisofs exited with code %d" % ret

if __name__ == "__main__":
    import progress.text
    builder = BuildISO('xxx.iso', '../disk', label="xxx cd v0.1", boot_image='isolinux/isolinux.bin', boot_catalog='isolinux/boot.cat')
    builder.run()
