#!/bin/bash

set -e

usage()
{
    echo "Usage: $0 <root> <command>"
}

ROOT="$1"
COMMAND="$2"

while getopts "hr:" opt; do
    case "$opt" in
        h) usage; exit 0;;
        r) ROOT="$OPTARG";;
#        s) SCRIPT="$OPTARG";;
        *) usage >&2; exit 1;;
    esac
done

if [ "$ROOT" == "" ]; then
    echo "No root given" >&2
    usage >&2; exit 1
fi

if [ "$COMMAND" == "" ]; then
    echo "No command given" >&2
    usage >&2; exit 1
fi

cd $ROOT
TMPFILE=`mktemp -p ./tmp/`

cp /etc/resolv.conf $ROOT/etc/resolv.conf

cat > $TMPFILE <<EOF
#!/bin/bash

FS="/proc /sys"

cd /

cleanup() {
    for i in \$FS; do
        echo "Unmounting \$i..."
        umount \$i
    done
}

for i in \$FS; do
    echo "Mounting \$i..."
    mount \$i
done

trap "cleanup" EXIT
$COMMAND
EOF

chmod +x $TMPFILE
chroot . $TMPFILE
RET=$?
rm -f $TMPFILE
rm -f $ROOT/etc/resolv.conf
exit $RET
