#  Copyright (c) 2010 Vitja Makarov
#
#  Author: Vitja Makarov <vitja.makarov@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

class SimpleConfigParser(dict):
    """Parser for simple config files

        KEY=value
        KEY="value"
        KEY='value'

        >>> p = SimpleConfigParser(defaults={'foo':'bar'})
        >>> p['foo']
        'bar'
        >>> p = SimpleConfigParser()
        >>> p.readfp(['foo=bar\\n'])
        >>> p['foo']
        'bar'
        >>> p.readfp(["foo=xxx=yyy"])
        >>> p['foo']
        'xxx=yyy'
        >>> p.readfp(["foo='bar'"])
        >>> p['foo']
        'bar'
        >>> p.readfp(['foo="bar"'])
        >>> p['foo']
        'bar'
    """

    def __init__(self, defaults=None):
        if defaults is not None:
            self.update(defaults)

    def read(self, fname):
        self.readfp(open(fname))

    def readfp(self, fp):
        for i in fp:
            i = i.strip()

            if not len(i) or i.startswith('#'):
                continue
            parts = i.split('=', 1)
            if len(parts) != 2:
                continue
            key = parts[0]
            value = parts[1]
            for s in "\"'":
                if value.startswith(s) and value.endswith(s):
                    value = value[1:-1]
                    break
            self[key] = value

if __name__ == "__main__":
    import doctest
    doctest.testmod()
